.ajax-upload-preview-area {
    /*background: #ddd;
    border-radius: 6px;
    border: 2px dashed #999;
    padding: 5px;
    margin-right: 5px;*/
    font-size: 12px;
    font-family: Arial, sans-serif;
    text-align:  center;
}
.ajax-upload-preview-area img {
    display: block;
    max-width: 500px;
    max-height: 350px;
    border: 1px solid #666;
    margin: 0 auto;
    margin-top: 5px;
}

.cropped-imag-preview{
    position: relative;
    min-height: 50px;
}

.upload-btn{
    bottom: 10px;
    left: 20px;
    position: absolute;
}



.btn-file > input {
    position: absolute;
    top: 0;
    right: 0;
    margin: 0;
    font-size: 23px;
    cursor: pointer;
    opacity: 0;
    filter: alpha(opacity=0);
    transform: translate(-300px, 0) scale(4);
    width: 100% !important;
    height: 30px;
    line-height: 30px;
}

.btn-file {
    position: relative;
    overflow: hidden;
    vertical-align: middle;
    display: block !important;
}

.image-body-modal{
    margin: 20px;
    border: #ddd 2px dashed;
    border-radius: 2px;
    -webkit-transition: border-color .218s;
    -moz-transition: border-color .218s;
    -o-transition: border-color .218s;
    transition: border-color .218s;
}